<?php 
/**
 * Plugin Name: Tracker Js Cdn Sync (Matomo Plugin)
 * Plugin URI: http://plugins.matomo.org/TrackerJsCdnSync
 * Description: Sync your tracker javascript files to CDN
 * Author: Saravanakumar
 * Author URI: https://github.com/SARAVANA1501/plugin-TrackerJsCdnSync
 * Version: 0.0.13
 */
?><?php
/**
 * Piwik - free/libre analytics platform
 *
 * @link https://matomo.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 */

namespace Piwik\Plugins\TrackerJsCdnSync;

use Piwik\Config;
use Piwik\Plugins\TrackerJsCdnSync\GenerateEmbedCode\TagManagerEmbedCodeGenerator;

 
if (defined( 'ABSPATH')
&& function_exists('add_action')) {
    $path = '/matomo/app/core/Plugin.php';
    if (defined('WP_PLUGIN_DIR') && WP_PLUGIN_DIR && file_exists(WP_PLUGIN_DIR . $path)) {
        require_once WP_PLUGIN_DIR . $path;
    } elseif (defined('WPMU_PLUGIN_DIR') && WPMU_PLUGIN_DIR && file_exists(WPMU_PLUGIN_DIR . $path)) {
        require_once WPMU_PLUGIN_DIR . $path;
    } else {
        return;
    }
    add_action('plugins_loaded', function () {
        if (function_exists('matomo_add_plugin')) {
            matomo_add_plugin(__DIR__, __FILE__, true);
        }
    });
}

class TrackerJsCdnSync extends \Piwik\Plugin
{
    public function registerEvents()
    {
        return array(
            'TagManager.containerFileChanged' => array('function' => 'onStaticFileUpdate', 'after' => true),
            'TagManager.containerFileDeleted' => array('function' => 'onStaticFileDelete', 'after' => true),
            'API.TagManager.getContainerEmbedCode.end' => 'onGetTagManagerCode',
            'API.TagManager.getContainerInstallInstructions.end' => 'onGetTagManagerCode'
        );
    }

    public function onStaticFileUpdate($file)
    {
        $this->getIOService()->AddFile($file);
    }

    public function onStaticFileDelete($file)
    {
        $this->getIOService()->DeleteFile($file);
    }

    private function getIOService(): IOService
    {
        $config = $this->getConfig();
        $ioServiceProvider = new IOServiceProvider($config);
        return $ioServiceProvider->GetIOService();
    }

    private function getConfig()
    {
        return Config::getInstance()->TrackerJsCdnSync;
    }

    public function onGetTagManagerCode(&$returnedValue, $extraInfo)
    {
        $config = $this->getConfig();
        $tagManagerEmbedCodeGenerator = new TagManagerEmbedCodeGenerator($config);
        $piwikBase = $this->getBaseUrl();
        $containerJs = $piwikBase . '/' . trim(\Piwik\Container\StaticContainer::get('TagManagerContainerWebDir'), '/') .'/';
        $tagManagerEmbedCodeGenerator->UpdateEmbedCode($containerJs, $returnedValue);
    }

    private function getBaseUrl()
    {
        $piwikBase = str_replace(array('http://', 'https://'), '', \Piwik\SettingsPiwik::getPiwikUrl());
        return rtrim($piwikBase, '/');
    }
}
